@@ -190,7 +190,7 @@ TEST(measlib_test, baseline_basic) {
 }
 
 //=========================================================================
-// test baseline out of range exceptions 
+// test baseline out of range 
 //=========================================================================
 TEST(measlib_test, baseline_out_of_range_exceptions) {
 
@@ -198,12 +198,10 @@ TEST(measlib_test, baseline_out_of_range_exceptions) {
     double var;
 
     /* Out of range: after last point */
-    EXPECT_THROW(stf::base(var, data, 0, data.size()),\
-         std::out_of_range);
+    EXPECT_TRUE(isnan(stf::base(var, data, 0, data.size())));
 
     /* Out of range: before first point */
-    EXPECT_THROW(stf::base(var, data, -1, data.size()-1),\
-         std::out_of_range);
+    EXPECT_TRUE(isnan(stf::base(var, data, -1, data.size()-1)));
 
 }
 
@@ -242,12 +240,12 @@ TEST(measlib_test, peak_out_of_range_exceptions) {
     double maxT;
 
     /* Out of range: before first point */
-    EXPECT_THROW(stf::peak(data, 0.0, 0, data.size(), 
-        1, stf::both, maxT), std::out_of_range);
+    EXPECT_TRUE(isnan(stf::peak(data, 0.0, 0, data.size(), 
+        1, stf::both, maxT)));
 
     /* Out of range: before first point */
-    EXPECT_THROW(stf::peak(data, 0.0, -1, data.size()-1, 
-        1, stf::both, maxT), std::out_of_range);
+    EXPECT_TRUE(isnan(stf::peak(data, 0.0, -1, data.size()-1, 
+        1, stf::both, maxT)));
 }
 
 //=========================================================================
@@ -346,21 +344,18 @@ TEST(measlib_test, threshold_windowLength_exceptions){
     
     /* Right peak cursor must be larger than windowLength
     long myRightPeakCursor = mywindowLength-1;
-    EXPECT_THROW(stf::threshold(data, 0, myRightPeakCursor, 
-        slope*dt, thrT, mywindowLength), 
-        std::out_of_range); */
+    EXPECT_TRUE(isnan(stf::threshold(data, 0, myRightPeakCursor, 
+        slope*dt, thrT, mywindowLength))); */
 
     /* Left peak cursor must be smaller than data.size()-windowLength */
     long myLeftPeakCursor = data.size()-mywindowLength; 
-    EXPECT_THROW(stf::threshold(data, myLeftPeakCursor, data.size()-1, 
-        slope*dt, thrT, mywindowLength), 
-        std::out_of_range);
+    EXPECT_TRUE(isnan(stf::threshold(data, myLeftPeakCursor, data.size()-1, 
+        slope*dt, thrT, mywindowLength)));
 
     /* Data size itself must be smaller than windowLength */
     mywindowLength = data.size()+1;
-    EXPECT_THROW(stf::threshold(data, 0, data.size()-1, \
-        slope*dt, thrT, mywindowLength), 
-        std::out_of_range);
+    EXPECT_TRUE(isnan(stf::threshold(data, 0, data.size()-1, \
+        slope*dt, thrT, mywindowLength)));
 
 }
 //=========================================================================
@@ -375,17 +370,14 @@ TEST(measlib_test, threshold_out_of_range){
     int windowLength = 1;
     
     /* Out of range: after last point*/
-    EXPECT_THROW(stf::threshold(mywave, 1, mywave.size(), 
-        slope*dt, thrT, windowLength),
-        std::out_of_range);
-    EXPECT_EQ(thrT,-1); 
+    EXPECT_TRUE(isnan(stf::threshold(mywave, 1, mywave.size(), 
+        slope*dt, thrT, windowLength)));
+    EXPECT_TRUE(isnan(thrT)); 
 
     /* Out of range: before first point*/
-    EXPECT_THROW(stf::threshold(mywave, -1, mywave.size()-1, 
-        slope*dt, thrT, windowLength),
-        std::out_of_range);
-    EXPECT_EQ(thrT,-1); 
-
+    EXPECT_TRUE(isnan(stf::threshold(mywave, -1, mywave.size()-1, 
+        slope*dt, thrT, windowLength)));
+    EXPECT_TRUE(isnan(thrT));
     
 }
 
@@ -453,15 +445,13 @@ TEST(measlib_test, half_duration_out_of_range_exceptions){
     double center = -1.0; /* index of the peak */ 
     
     /* Out of range: if center <0 */
-    EXPECT_THROW( stf::t_half(mywave, 0.0, 1.0, 1,
-        long(PI/dt)-1, center, t50LeftId, t50RigthId, t50Real),
-        std::out_of_range);
+    EXPECT_TRUE(isnan( stf::t_half(mywave, 0.0, 1.0, 1,
+        long(PI/dt)-1, center, t50LeftId, t50RigthId, t50Real)));
 
     /* Out of range: if center > recording length */
     center = mywave.size();
-    EXPECT_THROW( stf::t_half(mywave, 0.0, 1.0, 1,
-        long(PI/dt)-1, center, t50LeftId, t50RigthId, t50Real),
-        std::out_of_range);
+    EXPECT_TRUE(isnan( stf::t_half(mywave, 0.0, 1.0, 1,
+        long(PI/dt)-1, center, t50LeftId, t50RigthId, t50Real)));
 
 }
 
@@ -491,12 +481,12 @@ TEST(measlib_test, maxrise_out_of_range_exceptions) {
     double maxRiseT, maxRiseY;
     
     /* Out of range: peak cursor after last point */
-    EXPECT_THROW(stf::maxRise(data, 0, data.size(), \
-        maxRiseT, maxRiseY, 1), std::out_of_range);
+    EXPECT_TRUE(isnan(stf::maxRise(data, 0, data.size(), \
+        maxRiseT, maxRiseY, 1)));
 
     /* Out of range: peak cursor before first point
-    EXPECT_THROW(stf::maxRise(data, -1, data.size()-1, \
-    maxRiseT, maxRiseY, 1), std::out_of_range);*/
+    EXPECT_TRUE(isnan(stf::maxRise(data, -1, data.size()-1, \
+    maxRiseT, maxRiseY, 1)));*/
 
 }
 
@@ -512,18 +502,18 @@ TEST(measlib_test, maxrise_windowLength_exceptions){
     /* Right peak cursor must be larger than windowLength
     mywindowLength = 10;
     long myRightPeakCursor = mywindowLength-1;
-    EXPECT_THROW(stf::maxRise(data, 0, myRightPeakCursor, \
-    maxRiseT, maxRiseY, mywindowLength), std::out_of_range);*/
+    EXPECT_TRUE(isnan(stf::maxRise(data, 0, myRightPeakCursor, \
+    maxRiseT, maxRiseY, mywindowLength)));*/
 
     /* Left peak cursor must be smaller than data.size()-windowLength
     long myLeftPeakCursor = data.size()-mywindowLength; 
-    EXPECT_THROW(stf::maxRise(data, myLeftPeakCursor, data.size()-1 , \
-        maxRiseT, maxRiseY, mywindowLength), std::out_of_range); */
+    EXPECT_TRUE(isnan(stf::maxRise(data, myLeftPeakCursor, data.size()-1 , \
+        maxRiseT, maxRiseY, mywindowLength))); */
 
     /* Data size itself must be smaller than windowLength */
     mywindowLength = data.size()+1;
-    EXPECT_THROW(stf::maxRise(data, 0, data.size()-1, \
-        maxRiseT, maxRiseY, mywindowLength), std::out_of_range);
+    EXPECT_TRUE(isnan(stf::maxRise(data, 0, data.size()-1, \
+        maxRiseT, maxRiseY, mywindowLength)));
 
 }
 
@@ -573,12 +563,12 @@ TEST(measlib_test, maxdecay_out_of_range_exceptions) {
     double maxDecayT, maxDecayY;
 
     /* Out of range: peak cursor after last point */
-    EXPECT_THROW(stf::maxRise(data, 0, data.size(), \
-        maxDecayT, maxDecayY, 1), std::out_of_range);
+    EXPECT_TRUE(isnan(stf::maxRise(data, 0, data.size(), \
+        maxDecayT, maxDecayY, 1)));
 
     /* Out of range: peak cursor before first point
-    EXPECT_THROW(stf::maxRise(data, -1, data.size()-1, \
-    maxDecayT, maxDecayY, 1), std::out_of_range); */
+    EXPECT_TRUE(isnan(stf::maxRise(data, -1, data.size()-1, \
+    maxDecayT, maxDecayY, 1))); */
 
 }
 
@@ -594,18 +584,18 @@ TEST(measlib_test, maxdecay_windowLength_exceptions) {
     /* Right peak cursor must be larger than windowLength
     mywindowLength = 10;
     long myRightPeakCursor = mywindowLength-1;
-    EXPECT_THROW(stf::maxDecay(data, 0, myRightPeakCursor, \
-    maxDecayT, maxDecayY, mywindowLength), std::out_of_range); */
+    EXPECT_TRUE(isnan(stf::maxDecay(data, 0, myRightPeakCursor, \
+    maxDecayT, maxDecayY, mywindowLength))); */
 
     /* Left peak cursor must be smaller than data.size()-windowLength
     long myLeftPeakCursor = data.size()-mywindowLength; 
-    EXPECT_THROW(stf::maxRise(data, myLeftPeakCursor, data.size()-1 , \
-    maxDecayT, maxDecayY, mywindowLength), std::out_of_range);*/
+    EXPECT_TRUE(isnan(stf::maxRise(data, myLeftPeakCursor, data.size()-1 , \
+    maxDecayT, maxDecayY, mywindowLength)));*/
 
     /* Data size itself must be smaller than windowLength */
     mywindowLength = data.size()+1;
-    EXPECT_THROW(stf::maxRise(data, 0, data.size()-1, \
-        maxDecayT, maxDecayY, mywindowLength), std::out_of_range);
+    EXPECT_TRUE(isnan(stf::maxRise(data, 0, data.size()-1, \
+        maxDecayT, maxDecayY, mywindowLength)));
 }
 
 //=========================================================================
